@@ -12,6 +12,7 @@
 
 #include "libkita/favoritethreads.h"
 #include "libkita/board.h"
+#include "kitacacheinfo.h"
 
 #include <qmap.h>
 #include <qapplication.h>
@@ -64,17 +65,22 @@ void FavoriteListView::update()
 
   clear();
 
+  KitaCacheInfo* cache = KitaCacheInfo::getInstance();
+
   QDictIterator<Kita::Thread> it( threads );
   for(; it.current(); ++it) {
     const Kita::Thread* thread = it.current();
     const Kita::Board* board = thread->getBoard();
 
+    int readNum = cache->readNum( thread->datURL() );
+    int resNum = cache->resNum( thread->datURL() );
+
     new KListViewItem( this,
                        board->name(),
                        "",
                        thread->name(),
-                       QString("%1").arg(thread->resNum(), 4),
                        "",
+                       QString("%1").arg( readNum, 4 ),
                        "",
                        thread->datURL().fileName(),
                        thread->datURL().url() );
