@@ -43,12 +43,16 @@ public:
    */
   void update();
 
+public slots:
+  void updateThread( const Kita::Thread& updated_thread );
+
 private slots:
 
   /**
    * @param item clicked item.
    */
   void loadThread( QListViewItem* item );
+  void slotContextMenuRequested( QListViewItem*, const QPoint&, int );
 
 signals:
 
@@ -56,6 +60,7 @@ signals:
    * @param thread ɽ륹
    */
   void signalShowThread( const Kita::Thread& thread );
+  void signalShowThreadWithNewTab( const Kita::Thread& thread );
 };
 
 #endif
