@@ -211,6 +211,7 @@ void KitaMainWindow::writeConfig(KConfig *config)
 {
   config->setGroup("Global");
   config->writeEntry("Font", KitaConfig::font());
+  config->writeEntry( "ThreadFont", KitaConfig::threadFont() );
 }
 
 void KitaMainWindow::saveProperties(KConfig *config)
@@ -228,6 +229,7 @@ void KitaMainWindow::readConfig(KConfig* config)
 {
   config->setGroup("Global");
   KitaConfig::setFont(config->readFontEntry("Font"));
+  KitaConfig::setThreadFont( config->readFontEntry( "ThreadFont" ) );
 
   setFont(KitaConfig::font());
 }
@@ -403,6 +405,11 @@ void KitaMainWindow::optionsPreferences()
 
   connect(&dlg, SIGNAL( fontChanged( const QFont& ) ),
                 SLOT( setFont( const QFont& ) ) );
+  connect(&dlg, SIGNAL( threadFontChanged( const QFont& ) ),
+                SLOT( setThreadFont( const QFont& ) ) );
+
+  // XXX
+  dlg.setInitialSize( QSize( 500, 300 ) );
   if (dlg.exec()) {
     // redo your settings
   }
@@ -488,11 +495,16 @@ void KitaMainWindow::saveCache()
 void KitaMainWindow::setFont( const QFont& font )
 {
   KitaConfig::setFont(font);
-  m_threadView->setFont(font);
   m_subjectView->setFont(font);
   m_boardView->setFont(font);
 }
 
+void KitaMainWindow::setThreadFont( const QFont& font )
+{
+  KitaConfig::setThreadFont(font);
+  m_threadView->setFont(font);
+}
+
 void KitaMainWindow::slotWriteSucceeded()
 {
   statusBar()->message(i18n("posting succeeded."));
