@@ -17,7 +17,7 @@
 
 KitaCacheInfo* KitaCacheInfo::instance = 0;
 
-KitaCacheInfo::KitaCacheInfo() : m_vestedDict()
+KitaCacheInfo::KitaCacheInfo() : m_readDict()
 {
 }
 
@@ -33,29 +33,44 @@ KitaCacheInfo* KitaCacheInfo::getInstance()
   return instance;
 }
 
-int KitaCacheInfo::getVestedNum(const KURL& url)
+int KitaCacheInfo::readNum(const KURL& url)
 {
-  QString key = url.prettyURL();
-  if(m_vestedDict.contains(key)) {
-    return m_vestedDict[key];
+  QString key = url.url();
+  if( m_readDict.contains(key) ) {
+    return m_readDict[key];
   } else {
     return 0;
   }
 }
 
-void KitaCacheInfo::setVestedNum(const KURL& url, int num)
+void KitaCacheInfo::setReadNum(const KURL& url, int num)
 {
-  m_vestedDict.insert(url.prettyURL(), num);
+  m_readDict.insert(url.url(), num);
 }
-  
+
+int KitaCacheInfo::resNum( const KURL& url )
+{
+  QString key = url.url();
+  if( m_resNumDict.contains( key ) ) {
+    return m_resNumDict[ key ];
+  } else {
+    return 0;
+  }
+}
+
+void KitaCacheInfo::setResNum( const KURL& url, int num )
+{
+  m_resNumDict.insert( url.url(), num );
+}
+
 QDataStream& operator<<(QDataStream& s, KitaCacheInfo& c)
 {
-  s << c.m_vestedDict;
+  s << c.m_readDict;
   return s;
 }
 
 QDataStream& operator>>(QDataStream& s, KitaCacheInfo& c)
 {
-  s >> c.m_vestedDict;
+  s >> c.m_readDict;
   return s;
 }
