@@ -36,6 +36,7 @@
 #include "libkita/thread.h"
 
 enum SubjectViewRows {
+  Row_Mark,
   Row_ID,
   Row_Icon,
   Row_Subject,
@@ -54,6 +55,7 @@ KitaSubjectView::KitaSubjectView(QWidget *parent, const char *name)
     HideButton->setPixmap( SmallIcon("filter") );
   }
 
+  subjectList->addColumn("");
   subjectList->addColumn(i18n("No."));
   subjectList->addColumn("");
   subjectList->addColumn(i18n("Title"));
@@ -119,15 +121,23 @@ void KitaSubjectView::loadBoard(const Kita::Board& board)
 
     int readNum = cache->readNum( thread->datURL() );
     int resNum = thread->resNum();
-    new KListViewItem( subjectList,
-                       QString("%1").arg(i+1, 4),
-                       "",
-                       thread->name(),
-                       QString("%1").arg( resNum, 4 ),
-                       (readNum > 0) ? QString::number(readNum) : QString(""),
-                       (readNum > 0 && resNum != readNum) ? QString::number( resNum - readNum ) : QString(""),
-                       thread->datURL().fileName(),
-                       thread->datURL().url() );
+
+    KListViewItem* item = new KListViewItem( subjectList );
+    item->setText( Row_ID, QString("%1").arg(i+1, 4) );
+    item->setText( Row_Subject, thread->name() );
+    item->setText( Row_ResNum, QString("%1").arg( resNum, 4 ) );
+    item->setText( Row_Read, (readNum > 0) ? QString("%1").arg( readNum, 4 ) : QString("") );
+    item->setText( Row_Unread, (readNum > 0 && resNum != readNum) ? QString("%1").arg( resNum - readNum, 4 ) : QString("") );
+    item->setText( Row_DatName, thread->datURL().fileName() );
+    item->setText( Row_DatURL, thread->datURL().url() );
+
+    if ( readNum > 0 && resNum != readNum ) {
+      // ̤ɤ
+      item->setPixmap( Row_Mark, SmallIcon( "unread" ) );
+    } else if ( readNum > 0 ) {
+      // 
+      item->setPixmap( Row_Mark, SmallIcon( "read" ) );
+    }
   }
 
   if( HideButton->isOn() ) {
@@ -200,7 +210,7 @@ void KitaSubjectView::searchAll(const QStringList &query)
 
     QStringList::const_iterator queryIt = query.begin();
     for( ; queryIt != query.end(); ++queryIt ) {
-      if( item->text(Row_Subject).contains(*queryIt) ) {
+      if( item->text( Row_Subject ).contains( *queryIt, false ) ) {
         item->setPixmap(Row_Icon, SmallIcon("find") );
         m_hitList.append(item);
         break;
@@ -237,8 +247,8 @@ void KitaSubjectView::updateThread(const Kita::Thread& updated_thread)
     if( item->text(Row_DatURL) == updated_thread.datURL().url() ) {
       int resNum = item->text( Row_ResNum ).toInt();
       int readNum = updated_thread.resNum();
-      item->setText( Row_Read, QString::number( readNum ) );
-      item->setText( Row_Unread, readNum > 0 && resNum != readNum ? QString::number(resNum - readNum) : QString(""));
+      item->setText( Row_Read, QString("%1").arg( readNum, 4 ) );
+      item->setText( Row_Unread, readNum > 0 && resNum != readNum ? QString("%1").arg( resNum - readNum, 4 ) : QString(""));
     }
   }
 }
