@@ -10,6 +10,8 @@
 
 #include "board.h"
 
+#include <config.h>
+
 #include <kio/slaveconfig.h>
 #include <kio/netaccess.h>
 #include <kdebug.h>
@@ -66,7 +68,10 @@ const QPtrList<Thread> Board::getThreadList() const
   }
   QPtrList<Thread> threadList;
 
-  KIO::SlaveConfig::self()->setConfigData("http", m_boardURL.host() , "UserAgent", "Monazilla/1.00 (Kita/0.63)");
+  KIO::SlaveConfig::self()->setConfigData("http",
+    m_boardURL.host() ,
+    "UserAgent",
+    QString( "Monazilla/1.00 (Kita/%1)" ).arg( VERSION ) );
   QString tmpFile;
   if(KIO::NetAccess::download(subjectTxtURL(), tmpFile)) {
     QIODevice* tmpDevice = KFilterDev::deviceForFile(tmpFile, "application/x-gzip");
