@@ -10,6 +10,8 @@
 
 #include "favoritethreads.h"
 
+#include <kdebug.h>
+
 FavoriteThreads* FavoriteThreads::instance = 0;
 
 FavoriteThreads::FavoriteThreads()
@@ -28,19 +30,25 @@ FavoriteThreads* FavoriteThreads::getInstance()
   return instance;
 }
 
-void FavoriteThreads::insert( const Kita::Thread& thread )
+void FavoriteThreads::insert( const Kita::Thread* thread )
 {
-  m_threadMap.insert(thread.datURL().prettyURL(), thread);
+  if( ! m_threadDict.find( thread->datURL().url() ) ) {
+    m_threadDict.insert( thread->datURL().url(), thread );
+  }
 }
 
 void FavoriteThreads::remove( const QString& datURL )
 {
-  m_threadMap.remove( datURL );
+  m_threadDict.remove( datURL );
 }
 
 bool FavoriteThreads::contains( const QString& datURL ) const
 {
-  return m_threadMap.contains( datURL );
+  if( m_threadDict.find( datURL ) ) {
+    return true;
+  } else {
+    return false;
+  }
 }
 
 FavoriteThreads* FavoriteThreads::fromXml( const QString& xml )
@@ -57,12 +65,12 @@ FavoriteThreads* FavoriteThreads::fromXml( const QString& xml )
   if( parser.isValid() ) {
     QPtrList<Kita::Thread> threads = parser.getThreads();
 
-    instance->m_threadMap.clear();
+    instance->m_threadDict.clear();
     for( Kita::Thread* thread = threads.first(); thread; thread = threads.next() ) {
-      instance->insert( Kita::Thread( *(thread->getBoard()), thread->datURL(), thread->name(), thread->resNum() ) );
+      instance->insert( thread );
     }
   } else {
-    qDebug("inValid");
+    kdError() << "inValid" << endl;
   }
 
   return instance;
@@ -74,9 +82,10 @@ const QString FavoriteThreads::toXml() const
 
   ret += "<favorites xmlns=\"http://kita.sourceforge.jp/ns/favorites\">\n";
 
-  FavoriteThreads::const_iterator it;
-  for( it = threads().begin(); it != threads().end(); ++it ) {
-    ret += (*it).toXmlFragment();
+//  FavoriteThreads::const_iterator it;
+  QDictIterator<Kita::Thread> it( threads() );
+  for( ; it.current(); ++it ) {
+    ret += it.current()->toXmlFragment();
   }
   ret += "</favorites>\n";
 
@@ -85,7 +94,7 @@ const QString FavoriteThreads::toXml() const
 
 bool FavoriteThreads::test()
 {
-  qDebug("FavoriteThreads::test()");
+  kdDebug() << "FavoriteThreads::test()" << endl;
 
   QString xml = "<favorites xmlns=\"http://kita.sourceforge.jp/ns/favorites\">\n"
                 "<thread xmlns=\"http://kita.sourceforge.jp/ns/thread\">\n"
@@ -107,11 +116,15 @@ bool FavoriteThreads::test()
                 "</favorites>\n";
 
   FavoriteThreads* favorites = FavoriteThreads::fromXml( xml );
-  QMap<QString, Kita::Thread> threads = favorites->threads();
+  QDict<Kita::Thread> threads = favorites->threads();
 
-  if( threads.size() != 2 ) qDebug("inValid: line=%d", __LINE__);
-  if( threads.contains( "http://pc.2ch.net/linux/dat/1022744633.dat" ) != true ) qDebug("inValid: line=%d", __LINE__);
-  if( threads.contains( "http://pc.2ch.net/unix/dat/956134538.dat" ) != true ) qDebug("inValid: line=%d", __LINE__);
+  if( threads.size() != 2 ) kdError() << "inValid: line=" << __LINE__ << endl;
+  if( favorites->contains( "http://pc.2ch.net/linux/dat/1022744633.dat" ) != true ) {
+    kdError() << "inValid: line=" << __LINE__;
+  }
+  if( favorites->contains( "http://pc.2ch.net/unix/dat/956134538.dat" ) != true ) {
+    kdError() << "inValid: line=" << __LINE__;
+  }
   return true;
 }
 
