@@ -13,6 +13,7 @@
 
 #include "k2ch_articlefiletest.h"
 #include "urlconverttest.h"
+#include "commenttest.h"
 
 int main( int argc, char* argv[] )
 {
@@ -20,6 +21,7 @@ int main( int argc, char* argv[] )
 
   runner.addTest( K2chArticleFileTest::suite() );
   runner.addTest( URLConvertTest::suite() );
+  runner.addTest( CommentTest::suite() );
   runner.run( "" );
   return 0;
 }
