@@ -10,6 +10,8 @@
 
 #include "thread.h"
 
+#include <config.h>
+
 #include <kurl.h>
 #include <kio/slaveconfig.h>
 #include <kio/jobclasses.h>
@@ -315,8 +317,10 @@ bool ThreadXmlParser::characters( const QString& ch )
 QString ThreadAccess::get()
 {
   if ( m_thread.datURL().protocol() != "k2ch" ) {
-    KIO::SlaveConfig::self()->setConfigData("http", m_thread.datURL().host() ,
-                                          "UserAgent", "Monazilla/1.00 (Kita/0.63)");
+    KIO::SlaveConfig::self()->setConfigData("http",
+      m_thread.datURL().host(),
+      "UserAgent",
+      QString( "Monazilla/1.00 (Kita/%1)" ).arg( VERSION ) );
   }
 
   KIO::TransferJob* job = KIO::get(m_thread.datURL(), true, true);
