@@ -10,6 +10,11 @@
 
 #include "kitahtmlview.h"
 
+#include <khtml_part.h>
+
+#include <qapplication.h>
+#include <qclipboard.h>
+
 KitaHTMLView::KitaHTMLView( KHTMLPart* part, QWidget *parent, const char *name )
  : KHTMLView( part, parent, name )
 {
@@ -23,3 +28,15 @@ void KitaHTMLView::leaveEvent( QEvent* )
 {
   emit leave();
 }
+
+void KitaHTMLView::keyPressEvent( QKeyEvent* e )
+{
+  QClipboard* clipboard = QApplication::clipboard();
+
+  if( e->state() == ControlButton && e->key() == Key_C ) {
+    QString text = part()->selectedText();
+    clipboard->setText( text );
+  } else {
+    KHTMLView::keyPressEvent( e );
+  }
+}
