@@ -200,7 +200,7 @@ void KitaThreadView::update( const QString& result )
 
   text += "<html><head>";
   text += "</head>";
-  text += QString("<body style=\"font-size: %1pt; font-family: %2\">").arg( KitaConfig::font().pointSize() ).arg( KitaConfig::font().family() );
+  text += QString("<body style=\"font-size: %1pt; font-family: %2\">").arg( KitaConfig::threadFont().pointSize() ).arg( KitaConfig::font().family() );
 
   for( QStringList::iterator it = lines.begin(); it != lines.end(); ++it ) {
     QString line = (*it);
