@@ -11,35 +11,33 @@
 #ifndef _KITATHREADVIEW_H_
 #define _KITATHREADVIEW_H_
 
-#include <qwidget.h>
-#include <qcstring.h>
-#include <qtextbrowser.h>
-
-#include <kurl.h>
-#include <dom/dom_node.h>
-#include <kparts/browserextension.h>
-
 #include "kitathreadviewbase.h"
+
+#include <kparts/browserextension.h>
+#include <dom/html_base.h>
+
 #include "kita2ch.h"
 #include "libkita/thread.h"
-#include "libkita/board.h"
 
 class KURL;
 class KitaHTMLPart;
 class KitaWriteDialog;
+class QTextBrowser;
 
 #include <qvaluestack.h> // for gcc-2.9x
 template<class T> class QValueStack;
 
+namespace Kita {
+  class ThreadAccess;
+};
+
 namespace KIO {
   class Job;
 };
 
-#include <dom/html_base.h>
-
 /**
  *
- * Hideki Ikemoto
+ * @author Hideki Ikemoto <ikemo@users.sourceforge.jp>
  **/
 
 class KitaThreadView : public KitaThreadViewBase
@@ -49,10 +47,10 @@ class KitaThreadView : public KitaThreadViewBase
 public:
   KitaThreadView( QWidget *parent, const char *name=0 );
   ~KitaThreadView();
-  const QString threadSubject() const;
+  const QString threadName() const;
+  const KURL threadURL() const;
   void searchNext( const QStringList &input );
   void killJob();
-  KParts::BrowserExtension* browserExtension();
 
 public slots:
   void showThread( const Kita::Thread& thread );
