@@ -18,8 +18,8 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
+#include <klineedit.h>
 
-#include <qlineedit.h>
 #include <qtextedit.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
