@@ -36,6 +36,9 @@ KitaPreferences::KitaPreferences()
 
     connect( m_fontPage, SIGNAL( fontChanged( const QFont& ) ),
                          SIGNAL( fontChanged( const QFont& ) ) );
+
+    connect( m_fontPage, SIGNAL( threadFontChanged( const QFont& ) ),
+                         SIGNAL( threadFontChanged( const QFont& ) ) );
 }
 
 KitaFontPrefPage::KitaFontPrefPage( QWidget *parent )
@@ -44,6 +47,11 @@ KitaFontPrefPage::KitaFontPrefPage( QWidget *parent )
   fontButton->setText(KitaConfig::font().family());
   fontButton->setFont(KitaConfig::font());
   connect(fontButton, SIGNAL(clicked()), SLOT(slotFontButtonClicked()));
+
+  threadFontButton->setText( KitaConfig::threadFont().family() );
+  threadFontButton->setFont( KitaConfig::threadFont() );
+  connect( threadFontButton, SIGNAL( clicked() ),
+                             SLOT( slotThreadFontButtonClicked() ) );
 }
 
 void KitaFontPrefPage::slotFontButtonClicked()
@@ -57,6 +65,17 @@ void KitaFontPrefPage::slotFontButtonClicked()
   }
 }
 
+void KitaFontPrefPage::slotThreadFontButtonClicked()
+{
+  QFont font = threadFontButton->font();
+
+  if( KFontDialog::getFont( font, false, this ) == QDialog::Accepted ) {
+    threadFontButton->setText( font.family() );
+    threadFontButton->setFont( font );
+    emit threadFontChanged( font );
+  }
+}
+
 KitaPrefPageTwo::KitaPrefPageTwo( QWidget *parent )
     : QFrame(parent)
 {
